pywr.recorders.NodeRecorder
===========================

.. currentmodule:: pywr.recorders

.. autoclass:: NodeRecorder

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~NodeRecorder.after
      ~NodeRecorder.aggregated_value
      ~NodeRecorder.before
      ~NodeRecorder.finish
      ~NodeRecorder.load
      ~NodeRecorder.register
      ~NodeRecorder.reset
      ~NodeRecorder.setup
      ~NodeRecorder.unregister
      ~NodeRecorder.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~NodeRecorder.agg_func
      ~NodeRecorder.children
      ~NodeRecorder.comment
      ~NodeRecorder.epsilon
      ~NodeRecorder.ignore_nan
      ~NodeRecorder.is_constraint
      ~NodeRecorder.is_objective
      ~NodeRecorder.model
      ~NodeRecorder.name
      ~NodeRecorder.node
      ~NodeRecorder.parents
   
   